end_image.pdf

## Metadata

Title | end_image.pdf
Path | C:\Users\jenni\OneDrive\Documents\Code\burdoc\burdoc\tests\integration\data\inputs\end_image.pdf
Pages | 0
PDF Metadata: format | PDF 1.7
PDF Metadata: title |
PDF Metadata: author | Joe Ennis
PDF Metadata: subject |
PDF Metadata: keywords |
PDF Metadata: creator | Microsoft® Word for Microsoft 365
PDF Metadata: producer | Microsoft® Word for Microsoft 365
PDF Metadata: creationDate | D:20230403060612+01'00'
PDF Metadata: modDate | D:20230403060612+01'00'
PDF Metadata: trapped |
PDF Metadata: encryption |

## Contents

1. Page 0

#### Page 0

Path: | content.0.[3,3].bbox
Type: | addition

Key | Old | New
x1 |  | 281.9455871582031
y1 |  | 366.93560791015625
y0 |  | 299.015625
x0 |  | 72.02400207519531

Path: | content.0.[7,7].bbox
Type: | addition

Key | Old | New
x1 |  | 521.9444580078125
y1 |  | 273.0955810546875
y0 |  | 215.10557556152344
x0 |  | 315.42999267578125

Path: | content.0.[6,6].bbox
Type: | addition

Key | Old | New
x1 |  | 525.0398559570312
y1 |  | 175.26564025878906
y0 |  | 147.1855926513672
x0 |  | 315.42999267578125

Path: | content.0.[4,4].bbox
Type: | addition

Key | Old | New
x1 |  | 426.3999938964844
y1 |  | 729.3499755859375
y0 |  | 412.04998779296875
x0 |  | 188.5

Path: | content.0.[8,8].bbox
Type: | addition

Key | Old | New
x1 |  | 519.4688720703125
y1 |  | 321.0955810546875
y0 |  | 313.05560302734375
x0 |  | 315.42999267578125

Path: | content.0.[9,9].bbox
Type: | addition

Key | Old | New
x1 |  | 330.1992492675781
y1 |  | 331.05560302734375
y0 |  | 323.015625
x0 |  | 315.42999267578125

Lorem ipsum dolor sit amet. 33 distinctio expedita ut recusandae unde sit voluptas perspiciatis ab voluptatem sequi? Eum dignissimos dignissimos et optio rerum eum neque rerum! Est vitae harum ab vitae voluptatem qui iure quia rem voluptas consequatur non corrupti adipisci. Sit pariatur aliquam non iure ducimus est autem dolorem aut ipsum unde qui corrupti labore.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

Nam distinctio voluptatem At saepe nulla quo fuga autem. Et dicta natus eos rerum dolor ab nemo voluptas ex autem dignissimos ut temporibus dicta.

Lorem ipsum dolor sit amet. 33 distinctio expedita ut recusandae unde sit voluptas perspiciatis ab voluptatem sequi? Eum dignissimos dignissimos et optio rerum eum neque rerum! Est vitae harum ab vitae voluptatem qui iure quia rem voluptas consequatur non corrupti adipisci. Sit pariatur aliquam non iure ducimus est autem dolorem aut ipsum unde qui corrupti labore.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

Nam distinctio voluptatem At saepe nulla quo fuga autem. Et dicta natus eos rerum dolor ab nemo voluptas ex autem dignissimos ut temporibus dicta.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

"Old document" by storebukkebruse is licensed under CC BY

2.0.

Lorem ipsum dolor sit amet. 33 distinctio expedita ut recusandae unde sit voluptas perspiciatis ab voluptatem sequi? Eum dignissimos dignissimos et optio rerum eum neque rerum! Est vitae harum ab vitae voluptatem qui iure quia rem voluptas consequatur non corrupti adipisci. Sit pariatur aliquam non iure ducimus est autem dolorem aut ipsum unde qui corrupti labore.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

Nam distinctio voluptatem At saepe nulla quo fuga autem. Et dicta natus eos rerum dolor ab nemo voluptas ex autem dignissimos ut temporibus dicta.

Lorem ipsum dolor sit amet. 33 distinctio expedita ut recusandae unde sit voluptas perspiciatis ab voluptatem sequi? Eum dignissimos dignissimos et optio rerum eum neque rerum! Est vitae harum ab vitae voluptatem qui iure quia rem voluptas consequatur non corrupti adipisci. Sit pariatur aliquam non iure ducimus est autem dolorem aut ipsum unde qui corrupti labore.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

Nam distinctio voluptatem At saepe nulla quo fuga autem. Et dicta natus eos rerum dolor ab nemo voluptas ex autem dignissimos ut temporibus dicta.

Nam dolores ipsam qui adipisci consequatur et quisquam doloribus 33 omnis itaque sit recusandae atque non adipisci obcaecati sed tempora ipsum. Et galisum ducimus ab iste dolorem sit quia quaerat aut nihil voluptatem ut atque dolore vel praesentium unde a reprehenderit deserunt. Non fuga minima eos nobis quia ut officiis nihil.

"Old document" by storebukkebruse is licensed under CC BY

2.0.

Parent File Contents